==> jrdb_model-0.2.5.tar.gz: jrdb_model-0.2.5/src/jrdb_model/domain/returninfo.py <==
"""払い戻しデータ."""

from sqlalchemy import ForeignKey
from sqlalchemy.orm import Mapped, mapped_column

from ..sessioncontroll import db


class ReturninfoData(db.Model):
    """払戻金データ.

    Args:
        db (_type_): _description_

    """

    __tablename__ = "returninfo"
    racekey: Mapped[str] = mapped_column(
        ForeignKey("bangumi.racekey"), primary_key=True
    )
    win1_num: Mapped[int] = mapped_column()
    win1_ret: Mapped[int] = mapped_column()
    win2_num: Mapped[int] = mapped_column()
    win2_ret: Mapped[int] = mapped_column()
    win3_num: Mapped[int] = mapped_column()
    win3_ret: Mapped[int] = mapped_column()
    place1_num: Mapped[int] = mapped_column()
    place1_ret: Mapped[int] = mapped_column()
    place2_num: Mapped[int] = mapped_column()
    place2_ret: Mapped[int] = mapped_column()
    place3_num: Mapped[int] = mapped_column()
    place3_ret: Mapped[int] = mapped_column()
    place4_num: Mapped[int] = mapped_column()
    place4_ret: Mapped[int] = mapped_column()
    place5_num: Mapped[int] = mapped_column()
    place5_ret: Mapped[int] = mapped_column()
    wakuren1_num1: Mapped[int] = mapped_column()
    wakuren1_num2: Mapped[int] = mapped_column()
    wakuren1_ret: Mapped[int] = mapped_column()
    wakuren2_num1: Mapped[int] = mapped_column()
    wakuren2_num2: Mapped[int] = mapped_column()
    wakuren2_ret: Mapped[int] = mapped_column()
    wakuren3_num1: Mapped[int] = mapped_column()
    wakuren3_num2: Mapped[int] = mapped_column()
    wakuren3_ret: Mapped[int] = mapped_column()
    umaren1_num1: Mapped[int] = mapped_column()
    umaren1_num2: Mapped[int] = mapped_column()
    umaren1_ret: Mapped[int] = mapped_column()
    umaren2_num1: Mapped[int] = mapped_column()
    umaren2_num2: Mapped[int] = mapped_column()
    umaren2_ret: Mapped[int] = mapped_column()
    umaren3_num1: Mapped[int] = mapped_column()
    umaren3_num2: Mapped[int] = mapped_column()
    umaren3_ret: Mapped[int] = mapped_column()
    wide1_num1: Mapped[int] = mapped_column()
    wide1_num2: Mapped[int] = mapped_column()
    wide1_ret: Mapped[int] = mapped_column()
    wide2_num1: Mapped[int] = mapped_column()
    wide2_num2: Mapped[int] = mapped_column()
    wide2_ret: Mapped[int] = mapped_column()
    wide3_num1: Mapped[int] = mapped_column()
    wide3_num2: Mapped[int] = mapped_column()
    wide3_ret: Mapped[int] = mapped_column()
    wide4_num1: Mapped[int] = mapped_column()
    wide4_num2: Mapped[int] = mapped_column()
    wide4_ret: Mapped[int] = mapped_column()
    wide5_num1: Mapped[int] = mapped_column()
    wide5_num2: Mapped[int] = mapped_column()
    wide5_ret: Mapped[int] = mapped_column()
    wide6_num1: Mapped[int] = mapped_column()
    wide6_num2: Mapped[int] = mapped_column()
    wide6_ret: Mapped[int] = mapped_column()
    wide7_num1: Mapped[int] = mapped_column()
    wide7_num2: Mapped[int] = mapped_column()
    wide7_ret: Mapped[int] = mapped_column()
    umatan1_num1: Mapped[int] = mapped_column()
    umatan1_num2: Mapped[int] = mapped_column()
    umatan1_ret: Mapped[int] = mapped_column()
    umatan2_num1: Mapped[int] = mapped_column()
    umatan2_num2: Mapped[int] = mapped_column()
    umatan2_ret: Mapped[int] = mapped_column()
    umatan3_num1: Mapped[int] = mapped_column()
    umatan3_num2: Mapped[int] = mapped_column()
    umatan3_ret: Mapped[int] = mapped_column()
    umatan4_num1: Mapped[int] = mapped_column()
    umatan4_num2: Mapped[int] = mapped_column()
    umatan4_ret: Mapped[int] = mapped_column()
    umatan5_num1: Mapped[int] = mapped_column()
    umatan5_num2: Mapped[int] = mapped_column()
    umatan5_ret: Mapped[int] = mapped_column()
    umatan6_num1: Mapped[int] = mapped_column()
    umatan6_num2: Mapped[int] = mapped_column()
    umatan6_ret: Mapped[int] = mapped_column()
    sanrenpuku1_num1: Mapped[int] = mapped_column()
    sanrenpuku1_num2: Mapped[int] = mapped_column()
    sanrenpuku1_num3: Mapped[int] = mapped_column()
    sanrenpuku1_ret: Mapped[int] = mapped_column()
    sanrenpuku2_num1: Mapped[int] = mapped_column()
    sanrenpuku2_num2: Mapped[int] = mapped_column()
    sanrenpuku2_num3: Mapped[int] = mapped_column()
    sanrenpuku2_ret: Mapped[int] = mapped_column()
    sanrenpuku3_num1: Mapped[int] = mapped_column()
    sanrenpuku3_num2: Mapped[int] = mapped_column()
    sanrenpuku3_num3: Mapped[int] = mapped_column()
    sanrenpuku3_ret: Mapped[int] = mapped_column()
    sanrentan1_num1: Mapped[int] = mapped_column()
    sanrentan1_num2: Mapped[int] = mapped_column()
    sanrentan1_num3: Mapped[int] = mapped_column()
    sanrentan1_ret: Mapped[int] = mapped_column()
    sanrentan2_num1: Mapped[int] = mapped_column()
    sanrentan2_num2: Mapped[int] = mapped_column()
    sanrentan2_num3: Mapped[int] = mapped_column()
    sanrentan2_ret: Mapped[int] = mapped_column()
    sanrentan3_num1: Mapped[int] = mapped_column()
    sanrentan3_num2: Mapped[int] = mapped_column()
    sanrentan3_num3: Mapped[int] = mapped_column()
    sanrentan3_ret: Mapped[int] = mapped_column()
    sanrentan4_num1: Mapped[int] = mapped_column()
    sanrentan4_num2: Mapped[int] = mapped_column()
    sanrentan4_num3: Mapped[int] = mapped_column()
    sanrentan4_ret: Mapped[int] = mapped_column()
    sanrentan5_num1: Mapped[int] = mapped_column()
    sanrentan5_num2: Mapped[int] = mapped_column()
    sanrentan5_num3: Mapped[int] = mapped_column()
    sanrentan5_ret: Mapped[int] = mapped_column()
    sanrentan6_num1: Mapped[int] = mapped_column()
    sanrentan6_num2: Mapped[int] = mapped_column()
    sanrentan6_num3: Mapped[int] = mapped_column()
    sanrentan6_ret: Mapped[int] = mapped_column()

==> jrdb_model-0.2.8.tar.gz: jrdb_model-0.2.8/src/jrdb_model/domain/returninfo.py <==
"""払い戻しデータ."""

from sqlalchemy import ForeignKey, String
from sqlalchemy.orm import Mapped, mapped_column

from ..sessioncontroll import db


class ReturninfoData(db.Model):
    """払戻金データ.

    Args:
        db (_type_): _description_

    """

    __tablename__ = "returninfo"
    racekey: Mapped[str] = mapped_column(
        String(255), ForeignKey("bangumi.racekey"), primary_key=True
    )
    win1_num: Mapped[int] = mapped_column()
    win1_ret: Mapped[int] = mapped_column()
    win2_num: Mapped[int] = mapped_column()
    win2_ret: Mapped[int] = mapped_column()
    win3_num: Mapped[int] = mapped_column()
    win3_ret: Mapped[int] = mapped_column()
    place1_num: Mapped[int] = mapped_column()
    place1_ret: Mapped[int] = mapped_column()
    place2_num: Mapped[int] = mapped_column()
    place2_ret: Mapped[int] = mapped_column()
    place3_num: Mapped[int] = mapped_column()
    place3_ret: Mapped[int] = mapped_column()
    place4_num: Mapped[int] = mapped_column()
    place4_ret: Mapped[int] = mapped_column()
    place5_num: Mapped[int] = mapped_column()
    place5_ret: Mapped[int] = mapped_column()
    wakuren1_num1: Mapped[int] = mapped_column()
    wakuren1_num2: Mapped[int] = mapped_column()
    wakuren1_ret: Mapped[int] = mapped_column()
    wakuren2_num1: Mapped[int] = mapped_column()
    wakuren2_num2: Mapped[int] = mapped_column()
    wakuren2_ret: Mapped[int] = mapped_column()
    wakuren3_num1: Mapped[int] = mapped_column()
    wakuren3_num2: Mapped[int] = mapped_column()
    wakuren3_ret: Mapped[int] = mapped_column()
    umaren1_num1: Mapped[int] = mapped_column()
    umaren1_num2: Mapped[int] = mapped_column()
    umaren1_ret: Mapped[int] = mapped_column()
    umaren2_num1: Mapped[int] = mapped_column()
    umaren2_num2: Mapped[int] = mapped_column()
    umaren2_ret: Mapped[int] = mapped_column()
    umaren3_num1: Mapped[int] = mapped_column()
    umaren3_num2: Mapped[int] = mapped_column()
    umaren3_ret: Mapped[int] = mapped_column()
    wide1_num1: Mapped[int] = mapped_column()
    wide1_num2: Mapped[int] = mapped_column()
    wide1_ret: Mapped[int] = mapped_column()
    wide2_num1: Mapped[int] = mapped_column()
    wide2_num2: Mapped[int] = mapped_column()
    wide2_ret: Mapped[int] = mapped_column()
    wide3_num1: Mapped[int] = mapped_column()
    wide3_num2: Mapped[int] = mapped_column()
    wide3_ret: Mapped[int] = mapped_column()
    wide4_num1: Mapped[int] = mapped_column()
    wide4_num2: Mapped[int] = mapped_column()
    wide4_ret: Mapped[int] = mapped_column()
    wide5_num1: Mapped[int] = mapped_column()
    wide5_num2: Mapped[int] = mapped_column()
    wide5_ret: Mapped[int] = mapped_column()
    wide6_num1: Mapped[int] = mapped_column()
    wide6_num2: Mapped[int] = mapped_column()
    wide6_ret: Mapped[int] = mapped_column()
    wide7_num1: Mapped[int] = mapped_column()
    wide7_num2: Mapped[int] = mapped_column()
    wide7_ret: Mapped[int] = mapped_column()
    umatan1_num1: Mapped[int] = mapped_column()
    umatan1_num2: Mapped[int] = mapped_column()
    umatan1_ret: Mapped[int] = mapped_column()
    umatan2_num1: Mapped[int] = mapped_column()
    umatan2_num2: Mapped[int] = mapped_column()
    umatan2_ret: Mapped[int] = mapped_column()
    umatan3_num1: Mapped[int] = mapped_column()
    umatan3_num2: Mapped[int] = mapped_column()
    umatan3_ret: Mapped[int] = mapped_column()
    umatan4_num1: Mapped[int] = mapped_column()
    umatan4_num2: Mapped[int] = mapped_column()
    umatan4_ret: Mapped[int] = mapped_column()
    umatan5_num1: Mapped[int] = mapped_column()
    umatan5_num2: Mapped[int] = mapped_column()
    umatan5_ret: Mapped[int] = mapped_column()
    umatan6_num1: Mapped[int] = mapped_column()
    umatan6_num2: Mapped[int] = mapped_column()
    umatan6_ret: Mapped[int] = mapped_column()
    sanrenpuku1_num1: Mapped[int] = mapped_column()
    sanrenpuku1_num2: Mapped[int] = mapped_column()
    sanrenpuku1_num3: Mapped[int] = mapped_column()
    sanrenpuku1_ret: Mapped[int] = mapped_column()
    sanrenpuku2_num1: Mapped[int] = mapped_column()
    sanrenpuku2_num2: Mapped[int] = mapped_column()
    sanrenpuku2_num3: Mapped[int] = mapped_column()
    sanrenpuku2_ret: Mapped[int] = mapped_column()
    sanrenpuku3_num1: Mapped[int] = mapped_column()
    sanrenpuku3_num2: Mapped[int] = mapped_column()
    sanrenpuku3_num3: Mapped[int] = mapped_column()
    sanrenpuku3_ret: Mapped[int] = mapped_column()
    sanrentan1_num1: Mapped[int] = mapped_column()
    sanrentan1_num2: Mapped[int] = mapped_column()
    sanrentan1_num3: Mapped[int] = mapped_column()
    sanrentan1_ret: Mapped[int] = mapped_column()
    sanrentan2_num1: Mapped[int] = mapped_column()
    sanrentan2_num2: Mapped[int] = mapped_column()
    sanrentan2_num3: Mapped[int] = mapped_column()
    sanrentan2_ret: Mapped[int] = mapped_column()
    sanrentan3_num1: Mapped[int] = mapped_column()
    sanrentan3_num2: Mapped[int] = mapped_column()
    sanrentan3_num3: Mapped[int] = mapped_column()
    sanrentan3_ret: Mapped[int] = mapped_column()
    sanrentan4_num1: Mapped[int] = mapped_column()
    sanrentan4_num2: Mapped[int] = mapped_column()
    sanrentan4_num3: Mapped[int] = mapped_column()
    sanrentan4_ret: Mapped[int] = mapped_column()
    sanrentan5_num1: Mapped[int] = mapped_column()
    sanrentan5_num2: Mapped[int] = mapped_column()
    sanrentan5_num3: Mapped[int] = mapped_column()
    sanrentan5_ret: Mapped[int] = mapped_column()
    sanrentan6_num1: Mapped[int] = mapped_column()
    sanrentan6_num2: Mapped[int] = mapped_column()
    sanrentan6_num3: Mapped[int] = mapped_column()
    sanrentan6_ret: Mapped[int] = mapped_column()
